@@ -78,13 +78,13 @@ class UncleanedCharField(models.CharField):
         """
         choices = []
 
-        # FIXME: this maybe mistake with fields with same name in different refers
-        # dynamic_field = hs_models.DynamicField.objects.get(name=self.name)
-        dynamic_field = hs_models.find_dfields(refer='Contact', name=self.name)[0]
-
-
-        if dynamic_field.has_blank_option:
-            choices = super(UncleanedCharField, self).get_choices()
+        # FIXME: this maybe mistake on fields with same name in different refers
+        try:
+            dynamic_field = hs_models.find_dfields(name=self.name)[0]
+            if dynamic_field.has_blank_option:
+                choices = super(UncleanedCharField, self).get_choices()
+        except IndexError:
+            pass
 
         return choices or self._choices
 
